/** The fields that we make use of when reading a module package.json file  */
interface ModulePackageData {
    module?: string;
}
/**
 * Verify that the package has a `module` field present
 * @rejects if otherwise
 */
export declare function json(data: ModulePackageData): Promise<true>;
/**
 * Verify that the provided file contents is a valid ECMAScript Module
 * @param file the file contents that we wish to validate
 * @rejects if otherwise
 */
export declare function file(content: string): Promise<true>;
/**
 * Verify that the package URL declares a valid ECMAScript module file
 * @param packageRootURL the root CDN URL of the package, e.g. `https://unpkg.com/daet@1.11.0`
 * @rejects if otherwise
 */
export declare function remote(packageRootURL: string): Promise<true>;
/**
 * Verify that the published package declares a valid ECMAScript module file
 * Uses unpkg behind the scenes.
 * @param packageName the name of the published package that we should validate, e.g. `daet`
 * @param packageVersion the version of the published package that we should validate, e.g. `1.11.0`
 * @rejects if otherwise
 */
export declare function registry(packageName: string, packageVersion: string | number): Promise<true>;
export {};
//# sourceMappingURL=index.d.ts.map